@@ -503,6 +503,29 @@ func TestRunPackageNoImportCycle(t *testing.T) {
 		bufanalysistesting.NewFileAnnotation(t, "c1.proto", 5, 1, 5, 19, "PACKAGE_NO_IMPORT_CYCLE"),
 		bufanalysistesting.NewFileAnnotation(t, "d1.proto", 5, 1, 5, 19, "PACKAGE_NO_IMPORT_CYCLE"),
 	)
+	testLintWithOptions(
+		t,
+		"package_no_import_cycle",
+		"",
+		func(image bufimage.Image) bufimage.Image {
+			// Testing that import cycles are still detected via imports, but are
+			// not reported for imports, only for non-imports.
+			var newImageFiles []bufimage.ImageFile
+			for _, imageFile := range image.Files() {
+				if imageFile.FileDescriptorProto().GetPackage() == "b" {
+					newImageFiles = append(newImageFiles, bufimage.ImageFileWithIsImport(imageFile, true))
+				} else {
+					require.False(t, imageFile.IsImport())
+					newImageFiles = append(newImageFiles, imageFile)
+				}
+			}
+			newImage, err := bufimage.NewImage(newImageFiles)
+			require.NoError(t, err)
+			return newImage
+		},
+		bufanalysistesting.NewFileAnnotation(t, "c1.proto", 5, 1, 5, 19, "PACKAGE_NO_IMPORT_CYCLE"),
+		bufanalysistesting.NewFileAnnotation(t, "d1.proto", 5, 1, 5, 19, "PACKAGE_NO_IMPORT_CYCLE"),
+	)
 }
 
 func TestRunPackageSameDirectory(t *testing.T) {
@@ -604,14 +627,12 @@ func TestRunProtovalidate(t *testing.T) {
 		bufanalysistesting.NewFileAnnotation(t, "cel_field.proto", 116, 5, 120, 6, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_field.proto", 156, 5, 160, 6, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 22, 3, 26, 5, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 28, 3, 32, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 34, 3, 38, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 40, 3, 44, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 46, 3, 50, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 52, 3, 56, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 58, 3, 62, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 58, 3, 62, 5, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 64, 3, 68, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 70, 3, 74, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 76, 3, 80, 5, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_message.proto", 82, 5, 86, 7, "PROTOVALIDATE"),
@@ -631,12 +652,13 @@ func TestRunProtovalidate(t *testing.T) {
 		bufanalysistesting.NewFileAnnotation(t, "enum.proto", 28, 5, 28, 40, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "enum.proto", 36, 5, 36, 42, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "enum.proto", 39, 47, 39, 102, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 25, 7, 25, 43, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 30, 7, 30, 58, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 40, 5, 40, 41, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 45, 5, 45, 56, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 21, 7, 21, 43, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 26, 7, 26, 57, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 36, 5, 36, 41, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "extension.proto", 41, 5, 41, 55, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "field.proto", 18, 5, 18, 41, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "field.proto", 19, 5, 19, 56, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "field.proto", 19, 5, 19, 55, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "field.proto", 23, 52, 23, 102, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 24, 38, 24, 76, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 27, 5, 27, 43, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 29, 5, 29, 43, "PROTOVALIDATE"),
@@ -653,8 +675,6 @@ func TestRunProtovalidate(t *testing.T) {
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 83, 5, 83, 55, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 86, 5, 86, 57, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 87, 5, 87, 55, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "message.proto", 20, 3, 20, 49, "PROTOVALIDATE"),
-		bufanalysistesting.NewFileAnnotation(t, "message.proto", 27, 5, 27, 51, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "number.proto", 20, 5, 20, 42, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "number.proto", 25, 5, 25, 43, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "number.proto", 28, 5, 28, 43, "PROTOVALIDATE"),
@@ -1340,6 +1360,24 @@ func TestRunLintPolicyEmpty(t *testing.T) {
 		"policy_empty",
 		"",
 		nil,
+		bufanalysistesting.NewFileAnnotation(
+			t, "a.proto", 3, 1, 3, 11, "PACKAGE_DIRECTORY_MATCH",
+			bufanalysistesting.WithPolicyName("empty.policy.yaml"),
+		),
+		bufanalysistesting.NewFileAnnotation(
+			t, "a.proto", 3, 1, 3, 11, "PACKAGE_VERSION_SUFFIX",
+			bufanalysistesting.WithPolicyName("empty.policy.yaml"),
+		),
+	)
+}
+
+func TestRunLintPolicyDisableBuiltin(t *testing.T) {
+	t.Parallel()
+	testLintWithOptions(
+		t,
+		"policy_disablebuiltin",
+		"",
+		nil,
 	)
 }
 
